# This is a dedicated spec file for building jglobus for EPEL 5 and 6
# Instead of using maven - which is not available on RHEL/EPEL - ant
# is used for building. The ant build files were created using the
# maven ant plugin

%if "%{rhel}" == "5"
%global tomcat tomcat5
%global tomcatlib tomcat5-server-lib
%else
%global tomcat tomcat6
%global tomcatlib tomcat6-lib
%endif

Name:		jglobus
Version:	2.0.4
Release:	9.20121013git597e3ac%{?dist}
Summary:	Globus Java client libraries

#		Everything is Apache 2.0 except for one file that is MIT:
#		ssl-proxies/src/main/java/org/globus/tools/GridCertRequest.java
License:	ASL 2.0 and MIT
Group:		Development/Libraries
URL:		http://www.globus.org/toolkit/%{name}/
#		Source generated from a git checkout:
#		git clone http://github.com/%{name}/JGlobus
#		cd JGlobus
#		echo '*.jar export-ignore' > .gitattributes
#		git archive --prefix %{name}-%{version}-git597e3ac/ \
#		    --worktree-attributes \
#		    597e3ac | gzip > ../%{name}-%{version}-git597e3ac.tar.gz
Source0:	%{name}-%{version}-git597e3ac.tar.gz
#		Build with ant on old distributions
Source1:	%{name}-ant-%{version}.tar.gz
#		Adapting to tomcat 5
Patch0:		%{name}-tomcat5.patch

BuildArch:	noarch
#		There is no bouncycastle for ppc in EPEL5 abd ppc64 in EPEL6
ExcludeArch:	ppc ppc64
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:	jpackage-utils
BuildRequires:	java-devel
BuildRequires:	ant

BuildRequires:	jakarta-commons-codec
BuildRequires:	jakarta-commons-io
BuildRequires:	jakarta-commons-lang
BuildRequires:	jakarta-commons-logging
BuildRequires:	bouncycastle
BuildRequires:	log4j
BuildRequires:	%{tomcatlib}

%description
%{name} is a collection of Java client libraries for Globus Toolkit security,
GRAM and GridFTP.

%package ssl-proxies
Summary:	Globus Java - SSL and proxy certificate support
License:	ASL 2.0 and MIT
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-io
Requires:	jakarta-commons-lang
Requires:	jakarta-commons-logging
Requires:	bouncycastle
Requires:	log4j

%description ssl-proxies
Globus Java library with SSL and proxy certificate support

%package jsse
Summary:	Globus Java - SSL support
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-logging
Requires:	log4j

%description jsse
Globus Java library with SSL support

%package gss
Summary:	Globus Java - GSS-API implementation for SSL with proxies
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-io
Requires:	jakarta-commons-lang
Requires:	jakarta-commons-logging
Requires:	bouncycastle
Requires:	log4j

%description gss
Globus Java GSS-API implementation for SSL with proxies

%package gram
Summary:	Globus Java - Grid Resource Allocation and Management (GRAM)
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	%{name}-gss = %{version}-%{release}
Requires:	jakarta-commons-logging
Requires:	bouncycastle

%description gram
Globus Java library with GRAM support

%package gridftp
Summary:	Globus Java - GridFTP
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	%{name}-gss = %{version}-%{release}
Requires:	jakarta-commons-logging
Requires:	bouncycastle

%description gridftp
Globus Java library with GridFTP support

%package ssl-proxies-tomcat
Summary:	Globus Java - SSL and proxy certificate support for Tomcat
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	bouncycastle
Requires:	%{tomcatlib}

%description ssl-proxies-tomcat
Globus Java library with SSL and proxy certificate support for Tomcat

%package io
Summary:	Globus Java - IO
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	%{name}-gss = %{version}-%{release}
Requires:	%{name}-gram = %{version}-%{release}
Requires:	%{name}-gridftp = %{version}-%{release}
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-io
Requires:	jakarta-commons-lang
Requires:	jakarta-commons-logging
Requires:	bouncycastle
Requires:	log4j

%description io
Globus Java library with IO utilities

%package javadoc
Summary:	Javadocs for %{name}
License:	ASL 2.0 and MIT
Group:		Documentation
Requires:	jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -a 1 -n %{name}-%{version}-git597e3ac
%if "%{rhel}" == "5"
%patch0 -p1
%endif

%build
# Many tests requires network connections and a valid proxy certificate
export CLASSPATH=$(build-classpath bcprov log4j commons-codec commons-io commons-lang commons-logging %{tomcat}/catalina %{tomcat}/tomcat-coyote %{tomcat}/tomcat-util):ssl-proxies/target/ssl-proxies-2.0-SNAPSHOT.jar:jsse/target/jsse-2.0-SNAPSHOT.jar:gss/target/gss-2.0-SNAPSHOT.jar:gram/target/gram-2.0-SNAPSHOT.jar:gridftp/target/gridftp-2.0-SNAPSHOT.jar
ant -Dmaven.test.skip=true package javadoc

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_javadir}/%{name}
install -p -m 644 ssl-proxies/target/ssl-proxies-*.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies.jar
install -p -m 644 jsse/target/jsse-*.jar \
    %{buildroot}%{_javadir}/%{name}/jsse.jar
install -p -m 644 gss/target/gss-*.jar \
    %{buildroot}%{_javadir}/%{name}/gss.jar
install -p -m 644 gram/target/gram-*.jar \
    %{buildroot}%{_javadir}/%{name}/gram.jar
install -p -m 644 gridftp/target/gridftp-*.jar \
    %{buildroot}%{_javadir}/%{name}/gridftp.jar    
install -p -m 644 ssl-proxies-tomcat/target/ssl-proxies-tomcat-*.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies-tomcat.jar
install -p -m 644 io/target/io-*.jar \
    %{buildroot}%{_javadir}/%{name}/io.jar    

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr ssl-proxies/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies
cp -pr jsse/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/jsse
cp -pr gss/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gss
cp -pr gram/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gram
cp -pr gridftp/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gridftp
cp -pr ssl-proxies-tomcat/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies-tomcat
cp -pr io/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/io

%clean
rm -rf %{buildroot}

%files ssl-proxies
%defattr(-,root,root,-)
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/ssl-proxies.jar

%files jsse
%defattr(-,root,root,-)
%{_javadir}/%{name}/jsse.jar

%files gss
%defattr(-,root,root,-)
%{_javadir}/%{name}/gss.jar

%files gram
%defattr(-,root,root,-)
%{_javadir}/%{name}/gram.jar

%files gridftp
%defattr(-,root,root,-)
%{_javadir}/%{name}/gridftp.jar

%files ssl-proxies-tomcat
%defattr(-,root,root,-)
%{_javadir}/%{name}/ssl-proxies-tomcat.jar

%files io
%defattr(-,root,root,-)
%{_javadir}/%{name}/io.jar

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/%{name}

%changelog
* Sat Oct 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-9.20121013git597e3ac
- Git snapshot

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-8.20121010git8eefd68
- Git snapshot
- Drop patches applied upstream

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-7.20121010git5286c6b
- Git snapshot
- Drop patches applied upstream

* Thu Sep 27 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-6
- Drop spring framework dependency (based on pull request in github)
- Allows building on EPEL

* Mon Aug 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-5
- Build the tomcat module

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 04 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-3
- Adapt to changes in automatic maven rpm dependency generation

* Mon Apr 23 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-2
- Add MIT license tag

* Fri Apr 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-1
- First packaging
